@@ -6,7 +6,7 @@ Compatibility: Python3, wxPython Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
 Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: Aug.20.2025
+Rev: Sept.17.2025
 Code checker: flake8, pylint
 
 This file is part of Videomass.
@@ -65,8 +65,8 @@ from videomass.vdms_threads.shutdown import shutdown_system
 
 class MainFrame(wx.Frame):
     """
-    This is the main frame top window for panels
-    implementation and/or other children frames.
+    This main frame is the first ancestor aka the top-level
+    window for implementing panels and/or other child frames.
     """
     # colour rappresentetion in rgb
     AZURE_NEON = 158, 201, 232
@@ -313,8 +313,13 @@ class MainFrame(wx.Frame):
         if self.mediastreams:
             self.mediastreams.Raise()
             return
-        self.mediastreams = MediaStreams(self.data_files,
-                                         self.appdata['ostype'])
+
+        if self.filedropselected:  # is not None
+            indx = self.file_src.index(self.filedropselected)
+        else:
+            indx = 0
+
+        self.mediastreams = MediaStreams(self.data_files, selindx=indx)
         self.mediastreams.Show()
     # ------------------------------------------------------------------#
 
@@ -1020,16 +1025,17 @@ class MainFrame(wx.Frame):
 
     def view_logs(self, event, flog=None):
         """
-        Show to view log files dialog
+        Displays log file dialog
         flog: filename to select on showlog if any.
         """
         if self.showlogs:
             self.showlogs.Raise()
+            self.showlogs.on_flog_select(flog)
             return
 
         self.showlogs = ShowLogs(self,
                                  self.appdata['logdir'],
-                                 self.appdata['ostype'],
+                                 speclogname=flog,
                                  )
         self.showlogs.Show()
     # ------------------------------------------------------------------#
@@ -1406,7 +1412,7 @@ class MainFrame(wx.Frame):
         self.clearall.Enable(False)
         self.rename.Enable(False)
         self.rename_batch.Enable(False)
-        self.SetTitle(_('Videomass'))
+        self.SetTitle('Videomass')
         self.statusbar_msg(_('Ready'), None)
         self.Layout()
     # ------------------------------------------------------------------#
@@ -1837,6 +1843,7 @@ class MainFrame(wx.Frame):
                 msg = (_("Error while shutting down. Please see "
                          "file log for details."))
                 wx.LogError(msg)
+                self.view_logs(None, flog='Shutdown.log')
     # ------------------------------------------------------------------#
 
     def auto_exit(self):
