@@ -4,9 +4,9 @@ FileName: av_conversions.py
 Porpose: audio/video conversions interface
 Compatibility: Python3, wxPython4 Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: Mar.22.2024
+Rev: Sep.18.2025
 Code checker: flake8, pylint
 
 This file is part of Videomass.
@@ -31,7 +31,7 @@ import wx.lib.scrolledpanel as scrolled
 from pubsub import pub
 from videomass.vdms_utils.utils import update_timeseq_duration
 from videomass.vdms_utils.get_bmpfromsvg import get_bmp
-from videomass.vdms_io.io_tools import stream_play
+from videomass.vdms_threads.ffplay_file import FilePlay
 from videomass.vdms_io.checkup import check_files
 from videomass.vdms_dialogs.epilogue import Formula
 from videomass.vdms_dialogs import setting_profiles
@@ -42,6 +42,9 @@ from videomass.vdms_dialogs.filter_deinterlace import Deinterlace
 from videomass.vdms_dialogs.filter_scale import Scale
 from videomass.vdms_dialogs.filter_stab import VidstabSet
 from videomass.vdms_dialogs.filter_colorcorrection import ColorEQ
+from videomass.vdms_dialogs.singlechoicedlg import SingleChoice
+from videomass.vdms_dialogs.avconv_cmd_line import Raw_Cmd_Line
+from videomass.vdms_threads.ffmpeg import get_raw_cmdline_args
 from . video_encoders.video_no_enc import Video_No_Enc
 from . video_encoders.mpeg4 import Mpeg_4
 from . video_encoders.av1_aom import AV1_Aom
@@ -87,7 +90,7 @@ class AV_Conv(wx.Panel):
                 "SVT-AV1": {"-c:v libsvtav1": ["mkv", "webm"]},
                 "SVT-AV1 10-bit": {"-c:v libsvtav1": ["mkv", "webm"]},
                 "VP9": {"-c:v libvpx-vp9": ["webm", "mkv"]},
-                "Copy": {"-c:v copy": ["mkv", "mp4", "avi", "m4v", "ogv",
+                "Copy": {"-c:v copy": ["mkv", "mp4", "avi", "m4v",
                                        "webm", "Copy"]}
                 })
     # Namings in the audio format selection on Container combobox:
@@ -116,6 +119,7 @@ class AV_Conv(wx.Panel):
             bmpstab = get_bmp(icons['stabilizer'], ((16, 16)))
             bmpsaveprf = get_bmp(icons['addtoprst'], ((16, 16)))
             bmpcoloreq = get_bmp(icons['coloreq'], ((16, 16)))
+            bmpcmd = get_bmp(icons['cmdshow'], ((16, 16)))
         else:
             bmpplay = wx.Bitmap(icons['preview'], wx.BITMAP_TYPE_ANY)
             self.bmpreset = wx.Bitmap(icons['clear'], wx.BITMAP_TYPE_ANY)
@@ -128,12 +132,14 @@ class AV_Conv(wx.Panel):
             bmpstab = wx.Bitmap(icons['stabilizer'], wx.BITMAP_TYPE_ANY)
             bmpsaveprf = wx.Bitmap(icons['addtoprst'], wx.BITMAP_TYPE_ANY)
             bmpcoloreq = wx.Bitmap(icons['coloreq'], wx.BITMAP_TYPE_ANY)
+            bmpcmd = wx.Bitmap(icons['cmdshow'], wx.BITMAP_TYPE_ANY)
 
         # Default keys:values dictionary definition in this class
         self.opt = {"Media": "Video", "VidCmbxStr": "H.264",
                     "OutputFormat": "mkv", "VideoCodec": "-c:v libx264",
                     "ext_input": "", "Passes": "Auto", "InputDir": "",
                     "OutputDir": "", "SubtitleMap": "-map 0:s?",
+                    "SubtitleEnc": "",
                     "Deinterlace": "", "Interlace": "", "ColorEQ": "",
                     "PixelFormat": "", "Orientation": ["", ""], "Crop": "",
                     "CropColor": "", "Scale": "", "Setdar": "", "Setsar": "",
@@ -175,10 +181,12 @@ class AV_Conv(wx.Panel):
                                     | wx.CB_READONLY,
                                     )
         sizer_convin.Add(self.cmb_cont, 0, wx.LEFT | wx.CENTRE, 5)
-        self.btn_saveprst = wx.Button(self, wx.ID_ANY,
-                                      _("Save Preset"), size=(-1, -1))
+        self.btn_saveprst = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
         self.btn_saveprst.SetBitmap(bmpsaveprf, wx.LEFT)
         sizer_convin.Add(self.btn_saveprst, 0, wx.LEFT | wx.CENTRE, 20)
+        self.btn_cmd = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_cmd.SetBitmap(bmpcmd, wx.LEFT)
+        sizer_convin.Add(self.btn_cmd, 0, wx.LEFT | wx.CENTRE, 5)
         msg = _("Target")
         box1 = wx.StaticBox(self, wx.ID_ANY, msg)
         box_convin = wx.StaticBoxSizer(box1, wx.HORIZONTAL)
@@ -223,65 +231,65 @@ class AV_Conv(wx.Panel):
         self.videopanel.Show()
 
         # BOX Video filters
-        box4 = wx.StaticBox(self.nb_Video, wx.ID_ANY, _("Video Filters"))
+        box4 = wx.StaticBox(self.nb_Video, wx.ID_ANY, "")
         self.box_Vfilters = wx.StaticBoxSizer(box4, wx.VERTICAL)
-        self.btn_preview = wx.Button(self.nb_Video, wx.ID_ANY,
-                                     _("Preview"), size=(-1, -1))
-        self.btn_preview.SetBitmap(bmpplay, wx.LEFT)
+        sizer_nbVideo.Add(self.box_Vfilters, 0, wx.ALL | wx.EXPAND, 5)
+        self.filterVpanel = scrolled.ScrolledPanel(self.nb_Video, -1,
+                                                   size=(70, 700),
+                                                   style=wx.TAB_TRAVERSAL
+                                                   | wx.BORDER_NONE,
+                                                   name="panelscroll",
+                                                   )
+        sizer_Vfilter = wx.BoxSizer(wx.VERTICAL)
 
-        self.box_Vfilters.Add(self.btn_preview, 0, wx.ALL | wx.EXPAND, 5)
+        self.btn_preview = wx.Button(self.filterVpanel, wx.ID_ANY,
+                                     "", size=(40, -1))
+        self.btn_preview.SetBitmap(bmpplay, wx.LEFT)
+        sizer_Vfilter.Add(self.btn_preview, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_preview.Disable()
-        self.btn_reset = wx.Button(self.nb_Video, wx.ID_ANY,
-                                   _("Reset all"), size=(-1, -1))
+        self.btn_reset = wx.Button(self.filterVpanel, wx.ID_ANY,
+                                   "", size=(40, -1))
         self.btn_reset.SetBitmap(self.bmpreset, wx.LEFT)
-        self.box_Vfilters.Add(self.btn_reset, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_reset, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_reset.Disable()
-        lineflt = wx.StaticLine(self.nb_Video,
+        lineflt = wx.StaticLine(self.filterVpanel,
                                 wx.ID_ANY,
                                 pos=wx.DefaultPosition,
                                 size=wx.DefaultSize,
                                 style=wx.LI_HORIZONTAL,
                                 name=wx.StaticLineNameStr,
                                 )
-        self.box_Vfilters.Add(lineflt, 0, wx.ALL | wx.EXPAND, 10)
-        sizer_nbVideo.Add(self.box_Vfilters, 0, wx.ALL | wx.EXPAND, 5)
-        self.filterVpanel = scrolled.ScrolledPanel(self.nb_Video, -1,
-                                                   size=(180, 700),
-                                                   style=wx.TAB_TRAVERSAL
-                                                   | wx.BORDER_NONE,
-                                                   name="panelscroll",
-                                                   )
-        sizer_Vfilter = wx.BoxSizer(wx.VERTICAL)
+        sizer_Vfilter.Add(lineflt, 0, wx.ALL | wx.EXPAND, 10)
         self.btn_videosize = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                       _("Resize"), size=(-1, -1))
+                                       "", size=(40, -1))
         self.btn_videosize.SetBitmap(bmpresize, wx.LEFT)
-        sizer_Vfilter.Add(self.btn_videosize, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_videosize, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_crop = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                  _("Crop"), size=(-1, -1))
+                                  "", size=(40, -1))
         self.btn_crop.SetBitmap(bmpcrop, wx.LEFT)
-        sizer_Vfilter.Add(self.btn_crop, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_crop, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_rotate = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                    _("Transpose"), size=(-1, -1))
+                                    "", size=(40, -1))
         self.btn_rotate.SetBitmap(bmprotate, wx.LEFT)
 
-        sizer_Vfilter.Add(self.btn_rotate, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_rotate, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_lacing = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                    _("Deinterlace"), size=(-1, -1))
+                                    "", size=(40, -1))
         self.btn_lacing.SetBitmap(bmpdeinterlace, wx.LEFT)
-        sizer_Vfilter.Add(self.btn_lacing, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_lacing, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_denois = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                    _("Denoise"), size=(-1, -1))
+                                    "", size=(40, -1))
         self.btn_denois.SetBitmap(bmpdenoiser, wx.LEFT)
-        sizer_Vfilter.Add(self.btn_denois, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_denois, 0, wx.ALL | wx.CENTRE, 5)
         self.btn_vidstab = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                     _("Stabilize"), size=(-1, -1))
+                                     "", size=(40, -1))
         self.btn_vidstab.SetBitmap(bmpstab, wx.LEFT)
-        sizer_Vfilter.Add(self.btn_vidstab, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_vidstab, 0, wx.ALL | wx.CENTRE, 5)
 
         self.btn_coloreq = wx.Button(self.filterVpanel, wx.ID_ANY,
-                                     _("Equalize"), size=(-1, -1))
+                                     "", size=(40, -1))
         self.btn_coloreq.SetBitmap(bmpcoloreq, wx.LEFT)
-        sizer_Vfilter.Add(self.btn_coloreq, 0, wx.ALL | wx.EXPAND, 5)
+        sizer_Vfilter.Add(self.btn_coloreq, 0, wx.ALL | wx.CENTRE, 5)
 
         self.box_Vfilters.Add(self.filterVpanel, 1, wx.EXPAND)
         self.filterVpanel.SetSizer(sizer_Vfilter)  # set panel
@@ -319,10 +327,10 @@ class AV_Conv(wx.Panel):
         self.Fit()
         self.Layout()
         # ---------------------- Tooltips
-        tip = _('Save the current settings as a new preset profile for the '
-                'Preset Manager. You will find it in the Preset Manager '
-                'where you can use it quickly.')
+        tip = _('Save as a new profile of the Presets Manager.')
         self.btn_saveprst.SetToolTip(tip)
+        tip = _('Displays the RAW commands of the selected file.')
+        self.btn_cmd.SetToolTip(tip)
         tip = (_('Available video encoders. "Copy" means that the video '
                  'stream will not be re-encoded and will allow you (depending '
                  'on the encoder) to change the container, audio codec and a '
@@ -344,11 +352,15 @@ class AV_Conv(wx.Panel):
                  'convert them and apply audio filters such as '
                  'normalization.'))
         self.cmb_Media.SetToolTip(tip)
-        tip = _('Preview video filters')
-        self.btn_preview.SetToolTip(tip)
-        tip = (_('Clear all enabled filters. Remove all video filter '
-                 'data and apply default settings.'))
-        self.btn_reset.SetToolTip(tip)
+        self.btn_preview.SetToolTip(_('Preview video filters'))
+        self.btn_reset.SetToolTip(_('Disable active filters'))
+        self.btn_videosize.SetToolTip(_("Resize"))
+        self.btn_crop.SetToolTip(_("Crop"))
+        self.btn_rotate.SetToolTip(_("Transpose"))
+        self.btn_lacing.SetToolTip(_("Deinterlace"))
+        self.btn_denois.SetToolTip(_("Denoise"))
+        self.btn_vidstab.SetToolTip(_("Stabilize"))
+        self.btn_coloreq.SetToolTip(_("Equalize"))
 
         # ----------------------Binding (EVT)----------------------#
 
@@ -372,6 +384,8 @@ class AV_Conv(wx.Panel):
         self.Bind(wx.EVT_BUTTON, self.on_audio_preview,
                   self.audioenc.btn_audio_preview)
 
+        self.Bind(wx.EVT_BUTTON, self.on_cmd_line, self.btn_cmd)
+
         #  initialize default layout:
         self.cmb_vencoder.SetSelection(2)
         self.cmb_Media.SetSelection(0), self.cmb_cont.SetSelection(0)
@@ -464,6 +478,7 @@ class AV_Conv(wx.Panel):
         self.vencoder_panel_set()
         self.audioenc.audio_default()
         self.audioenc.set_audio_radiobox(None)
+        self.miscfunc.set_subt_radiobox()
     # ------------------------------------------------------------------#
 
     def on_Media(self, event):
@@ -483,12 +498,14 @@ class AV_Conv(wx.Panel):
             self.opt["OutputFormat"] = self.cmb_cont.GetValue()
             self.vencoder_panel_set()
             self.audioenc.set_audio_radiobox(None)
+            self.miscfunc.set_subt_radiobox()
 
         elif self.cmb_Media.GetValue() == 'Video':
             self.opt["Media"] = 'Video'
             self.cmb_vencoder.Enable()
             self.cmb_vencoder.SetSelection(2)
             self.videoCodec(self)
+            self.miscfunc.set_subt_radiobox()
     # ------------------------------------------------------------------#
 
     def on_Container(self, event):
@@ -500,6 +517,7 @@ class AV_Conv(wx.Panel):
         else:
             self.opt["OutputFormat"] = self.cmb_cont.GetValue()
         self.audioenc.set_audio_radiobox(None)
+        self.miscfunc.set_subt_radiobox()
     # ------------------------------------------------------------------#
 
     def on_video_preview(self, event):
@@ -511,19 +529,27 @@ class AV_Conv(wx.Panel):
         if not fget or not self.opt["VFilters"]:
             return
         if self.opt["Vidstabtransform"]:
-            wx.MessageBox(_("Unable to preview Video Stabilizer filter"),
+            wx.MessageBox(_("To preview Stabilize filter, please click "
+                            "Preview button on Video Stabilizer Tool"),
                           "Videomass", wx.ICON_INFORMATION, self)
             return
 
         flt = self.opt["VFilters"]
-        if self.parent.checktimestamp:
-            flt = f'{flt},"{self.parent.cmdtimestamp}"'
+        autoexit = '-autoexit' if self.parent.autoexit else ''
 
-        stream_play(self.parent.file_src[fget[1]],
-                    self.parent.time_seq,
-                    flt,
-                    self.parent.autoexit
-                    )
+        if self.parent.checktimestamp:
+            args = (f'{autoexit} -i "{self.parent.file_src[fget[1]]}" '
+                    f'{self.parent.time_seq} '
+                    f'{flt},"{self.parent.cmdtimestamp}"')
+        else:
+            args = f'{autoexit} -i "{self.parent.file_src[fget[1]]}" {flt}'
+        try:
+            with open(self.parent.file_src[fget[1]], encoding='utf-8'):
+                FilePlay(self.GetParent(), args)
+        except IOError:
+            wx.MessageBox(_("Invalid or unsupported file:  %s") % (filepath),
+                          "Videomass", wx.ICON_EXCLAMATION, self)
+            return
     # ------------------------------------------------------------------#
 
     def on_audio_preview(self, event):
@@ -840,17 +866,18 @@ class AV_Conv(wx.Panel):
             else:
                 kwargs = self.video_std()
 
-        elif self.opt["Media"] == 'Audio':
+            return kwargs
 
-            if self.opt["EBU"][0] == 'EBU R128 (High-Quality)':
-                kwargs = self.audio_ebu()
-            else:
-                kwargs = self.audio_std()
+        # self.opt["Media"] == 'Audio':
+        if self.opt["EBU"][0] == 'EBU R128 (High-Quality)':
+            kwargs = self.audio_ebu()
+        else:
+            kwargs = self.audio_std()
 
         return kwargs
     # ------------------------------------------------------------------#
 
-    def check_options(self, index=None):
+    def check_options(self, index=None, checkexists=True):
         """
         Update entries and file check.
         """
@@ -874,10 +901,10 @@ class AV_Conv(wx.Panel):
                                 self.appdata['filesuffix'],
                                 self.opt["OutputFormat"],
                                 outfilenames,
+                                checkexists=checkexists,
                                 )
         if not filecheck:  # User changing idea or not such files exist
             return None
-
         return filecheck
     # ------------------------------------------------------------------#
 
@@ -980,8 +1007,8 @@ class AV_Conv(wx.Panel):
                 cmd2 = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
                         f'{self.opt["passlogfile2"]} '
                         f'{self.opt["CmdAudioParams"]} '
-                        f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
-                        f'{self.opt["MetaData"]}'
+                        f'{self.opt["SubtitleEnc"]} {self.opt["SubtitleMap"]} '
+                        f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
                         )
             else:  # single pass
                 cmd1 = (f'-filter:v {self.opt["Vidstabdetect"]} '
@@ -990,8 +1017,8 @@ class AV_Conv(wx.Panel):
                         )
                 cmd2 = (f'{self.opt["CmdVideoParams"]} '
                         f'{self.opt["VFilters"]} {self.opt["CmdAudioParams"]} '
-                        f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
-                        f'{self.opt["MetaData"]}'
+                        f'{self.opt["SubtitleEnc"]} {self.opt["SubtitleMap"]} '
+                        f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
                         )
             pass1, pass2 = " ".join(cmd1.split()), " ".join(cmd2.split())
             kwargs = {'type': 'Two pass EBU', 'args': [pass1, pass2],
@@ -1009,8 +1036,8 @@ class AV_Conv(wx.Panel):
                     )
             cmd2 = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
                     f'{self.opt["CmdAudioParams"]} {self.opt["EBU"][1]} '
-                    f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
-                    f'{self.opt["MetaData"]}'
+                    f'{self.opt["SubtitleEnc"]} {self.opt["SubtitleMap"]} '
+                    f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
                     )
             pass1, pass2 = " ".join(cmd1.split()), " ".join(cmd2.split())
             kwargs = {'type': 'Two pass VIDSTAB', 'args': [pass1, pass2],
@@ -1031,8 +1058,8 @@ class AV_Conv(wx.Panel):
 
             args = (f'{self.opt["CmdVideoParams"]} '
                     f'{self.opt["CmdAudioParams"]} {self.opt["EBU"][1]} '
-                    f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
-                    f'{self.opt["MetaData"]}'
+                    f'{self.opt["SubtitleEnc"]} {self.opt["SubtitleMap"]} '
+                    f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
                     )
             pass1, pass2 = " ".join(args.split()), ''
             kwargs = {'type': 'One pass', 'args': [pass1, pass2],
@@ -1046,8 +1073,9 @@ class AV_Conv(wx.Panel):
                     )
             cmd2 = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
                     f'{self.opt["passlogfile2"]} {self.opt["CmdAudioParams"]} '
-                    f'{self.opt["EBU"][1]} {self.opt["SubtitleMap"]} '
-                    f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
+                    f'{self.opt["EBU"][1]} {self.opt["SubtitleEnc"]} '
+                    f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
+                    f'{self.opt["MetaData"]}'
                     )
             pass1, pass2 = " ".join(cmd1.split()), " ".join(cmd2.split())
             kwargs = {'type': 'Two pass', 'args': [pass1, pass2],
@@ -1057,14 +1085,16 @@ class AV_Conv(wx.Panel):
         elif self.opt["Passes"] == "Auto":
             args = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
                     f'{self.opt["CmdAudioParams"]} {self.opt["EBU"][1]} '
-                    f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
-                    f'{self.opt["MetaData"]}'
+                    f'{self.opt["SubtitleEnc"]} {self.opt["SubtitleMap"]} '
+                    f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
                     )
             pass1, pass2 = " ".join(args.split()), ''
             kwargs = {'type': 'One pass', 'args': [pass1, pass2],
                       'volume': [vol[5] for vol in audnorm],
                       'preset name': 'A/V Conversions - Video standard',
                       }
+        else:
+            return None
         return kwargs
     # ------------------------------------------------------------------#
 
@@ -1081,8 +1111,9 @@ class AV_Conv(wx.Panel):
                      f'-filter:a: {self.opt["EBU"][1]} -vn -sn -dn  -f null'
                      )
             cmd_2 = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
-                     f'{self.opt["CmdAudioParams"]} {self.opt["SubtitleMap"]} '
-                     f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
+                     f'{self.opt["CmdAudioParams"]} {self.opt["SubtitleEnc"]} '
+                     f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
+                     f'{self.opt["MetaData"]}'
                      )
             pass1 = " ".join(cmd_1.split())
             pass2 = " ".join(cmd_2.split())
@@ -1100,8 +1131,9 @@ class AV_Conv(wx.Panel):
                      )
             cmd_2 = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
                      f'{self.opt["passlogfile2"]} '
-                     f'{self.opt["CmdAudioParams"]} {self.opt["SubtitleMap"]} '
-                     f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
+                     f'{self.opt["CmdAudioParams"]} {self.opt["SubtitleEnc"]} '
+                     f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
+                     f'{self.opt["MetaData"]}'
                      )
             pass1 = " ".join(cmd_1.split())
             pass2 = " ".join(cmd_2.split())
@@ -1115,8 +1147,9 @@ class AV_Conv(wx.Panel):
                      f'-filter:a: {self.opt["EBU"][1]} -vn -sn -dn -f null'
                      )
             cmd_2 = (f'{self.opt["CmdVideoParams"]} {self.opt["VFilters"]} '
-                     f'{self.opt["CmdAudioParams"]} {self.opt["SubtitleMap"]} '
-                     f'{self.opt["Chapters"]} {self.opt["MetaData"]}'
+                     f'{self.opt["CmdAudioParams"]} {self.opt["SubtitleEnc"]} '
+                     f'{self.opt["SubtitleMap"]} {self.opt["Chapters"]} '
+                     f'{self.opt["MetaData"]}'
                      )
             pass1 = " ".join(cmd_1.split())
             pass2 = " ".join(cmd_2.split())
@@ -1195,11 +1228,20 @@ class AV_Conv(wx.Panel):
         else:
             dest = self.appdata['outputdir']
 
+        if self.opt["Media"] == 'Audio':
+            subtitles = _('Disabled')
+        elif not self.opt["SubtitleEnc"]:
+            subtitles = _('Auto')
+        elif self.opt["SubtitleEnc"] == '-sn':
+            subtitles = _('No Subtitles')
+        else:
+            subtitles = self.opt["SubtitleEnc"].split()[1]
+
         passes = '1' if kwa["args"][1] == '' else '2'
 
         keys = (_("Batch processing items\nDestination\nAutomation/Preset"
-                  "\nEncoding passes\nOutput Format"
-                  "\nVideo Codec\nAudio Codec\nAudio Normalization"
+                  "\nEncoding passes\nOutput Format\nVideo Codec"
+                  "\nSubtitle Stream\nAudio Codec\nAudio Normalization"
                   "\nOutput multimedia type\nStart of segment"
                   "\nClip duration"
                   ))
@@ -1209,6 +1251,7 @@ class AV_Conv(wx.Panel):
                 f'{passes}\n'
                 f'{outputformat}\n'
                 f'{self.opt["VidCmbxStr"]}\n'
+                f'{subtitles}\n'
                 f'{self.opt["AudioCodStr"]}\n'
                 f'{normalize}\n'
                 f'{self.opt["Media"]}\n'
@@ -1218,10 +1261,47 @@ class AV_Conv(wx.Panel):
         return {'key': keys, 'val': vals}
     # ------------------------------------------------------------------#
 
-    def on_saveprst(self, event):
+    def on_cmd_line(self, event):
         """
-        Save current setting as profile for the Presets
-        Manager panel
+        Displays the raw command line output.
+        """
+        try:
+            index = self.parent.file_src.index(self.parent.filedropselected)
+        except ValueError:
+            wx.MessageBox(_("Have to select an item in the file list first"),
+                          'Videomass', wx.ICON_INFORMATION, self)
+            return None
+
+        check = self.check_options(index=index, checkexists=False)
+        if not check:
+            return None
+        f_src, f_dest = check[0][0], check[1][0]
+        kwargs = self.get_codec_args()
+        dur, ss, et = update_timeseq_duration(self.parent.time_seq,
+                                              self.parent.duration
+                                              )
+        kwargs['extension'] = self.opt["OutputFormat"]
+        kwargs['pre-input-1'], kwargs['pre-input-2'] = '', ''
+        kwargs['source'] = f_src
+        kwargs['destination'] = f_dest
+        kwargs["duration"] = dur[index]
+        kwargs['start-time'], kwargs['end-time'] = ss, et
+        if kwargs.get("volume"):
+            kwargs["volume"] = kwargs["volume"][index]
+        else:
+            kwargs["volume"] = ''
+
+        cmd = get_raw_cmdline_args(**kwargs)
+
+        displaycmd = Raw_Cmd_Line(self, *cmd)
+        displaycmd.ShowModal()
+
+        return None
+    # ------------------------------------------------------------------#
+
+    def save_to_preset(self, presetname):
+        """
+        Save the current profile in the Preset Manager
         """
         if self.cmb_Media.GetValue() == 'Video':
             self.opt["CmdVideoParams"] = self.videopanel.video_options()
@@ -1234,30 +1314,18 @@ class AV_Conv(wx.Panel):
             else:
                 kwargs = self.video_std()
 
-        elif self.cmb_Media.GetValue() == 'Audio':
+        else:  # self.cmb_Media.GetValue() == 'Audio'
             self.opt["CmdAudioParams"] = self.audioenc.audio_options()
             if self.opt["EBU"][0] == 'EBU R128 (High-Quality)':
                 kwargs = self.audio_ebu()
             else:
                 kwargs = self.audio_std()
 
-        with wx.FileDialog(
-                None, _("Choose a Videomass preset..."),
-                defaultDir=os.path.join(self.appdata['confdir'], 'presets'),
-                wildcard="Videomass presets (*.json;)|*.json;",
-                style=wx.FD_OPEN | wx.FD_FILE_MUST_EXIST) as fileDialog:
-
-            if fileDialog.ShowModal() == wx.ID_CANCEL:
-                return
-
-            filename = os.path.splitext(fileDialog.GetPath())[0]
-            basename = os.path.basename(filename)
-
-            title = _('New Profile - Preset "{0}"').format(basename)
-
+        fname = os.path.basename(presetname)
+        title = _('Write profile on «{0}»').format(fname)
         args = kwargs["args"][0], kwargs["args"][1], self.opt["OutputFormat"]
         with setting_profiles.SettingProfile(self, 'addprofile',
-                                             basename,
+                                             presetname,
                                              args,
                                              title,
                                              ) as prstdialog:
@@ -1265,3 +1333,66 @@ class AV_Conv(wx.Panel):
             if prstdialog.ShowModal() == wx.ID_CANCEL:
                 return
         self.parent.PrstsPanel.presets_refresh(self)
+        return
+    # ------------------------------------------------------------------#
+
+    def preset_name(self, action):
+        """
+        Return the preset name
+        """
+        defaultdir = os.path.join(self.appdata['confdir'], 'presets')
+        if action == 0:
+            with wx.FileDialog(self, _("Enter name for new preset"),
+                               defaultDir=defaultdir,
+                               wildcard="Videomass preset (*.json;)|*.json;",
+                               style=wx.FD_SAVE
+                               | wx.FD_OVERWRITE_PROMPT) as fileDialog:
+                fileDialog.SetFilename('New preset.json')
+                if fileDialog.ShowModal() == wx.ID_CANCEL:
+                    return None
+                filename = fileDialog.GetPath()
+                if os.path.splitext(filename)[1].strip() != '.json':
+                    wx.LogError(_('Invalid file name, make sure to provide a '
+                                  'valid name including the «.json» '
+                                  'extension'))
+                    return None
+            try:
+                with open(filename, 'w', encoding='utf-8') as file:
+                    file.write('[]')
+            except IOError:
+                wx.LogError(_("Cannot save current "
+                              "data in file «{}».").format(filename))
+                return None
+
+        elif action == 1:
+            with wx.FileDialog(self, _("Open Videomass preset"),
+                               defaultDir=defaultdir,
+                               wildcard="Videomass preset (*.json;)|*.json;",
+                               style=wx.FD_OPEN
+                               | wx.FD_FILE_MUST_EXIST) as fileDialog:
+                if fileDialog.ShowModal() == wx.ID_CANCEL:
+                    return None
+                filename = fileDialog.GetPath()
+        else:
+            return None
+
+        return filename
+    # ------------------------------------------------------------------#
+
+    def on_saveprst(self, event):
+        """
+        Asks to the user where add the new profile
+        """
+        caption = _('Videomass - Save new profile')
+        message = _('Where do you want to save this profile?')
+        choices = (_('Save the profile to a new preset'),
+                   _('Save the profile to an existing preset'))
+        with SingleChoice(self, caption, message, choices, 0) as dlg:
+            if dlg.ShowModal() == wx.ID_OK:
+                presetname = self.preset_name(dlg.getvalue())
+            else:
+                return
+        if not presetname:
+            return
+
+        self.save_to_preset(presetname)
