@@ -4,9 +4,9 @@ Name: long_processing_task.py
 Porpose: Console to show logging messages during processing
 Compatibility: Python3, wxPython4 Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: Apr.20.2024
+Rev: Aug.07.2025
 Code checker: flake8, pylint
 
 This file is part of Videomass.
@@ -32,7 +32,7 @@ import wx
 from videomass.vdms_dialogs.widget_utils import notification_area
 from videomass.vdms_io.make_filelog import make_log_template
 from videomass.vdms_threads.ffmpeg import FFmpeg
-from videomass.vdms_threads.picture_exporting import PicturesFromVideo
+from videomass.vdms_threads.image_extractor import PicturesFromVideo
 from videomass.vdms_threads.concat_demuxer import ConcatDemuxer
 from videomass.vdms_threads.slideshow import SlideshowMaker
 from videomass.vdms_utils.utils import (time_to_integer, integer_to_time)
@@ -110,7 +110,7 @@ class LogOut(wx.Panel):
     # used msg on text
     MSG_done = '[Videomass]: SUCCESS !'
     MSG_failed = '[Videomass]: FAILED !'
-    MSG_stop = '[Videomass]: STOP command received. Interrupting !'
+    MSG_stop = '[Videomass]: STOP command received.'
     MSG_taskfailed = _('Sorry, all task failed !')
     MSG_fatalerror = _("The process was stopped due to a fatal error.")
     MSG_interrupted = _('Interrupted Process !')
@@ -141,7 +141,6 @@ class LogOut(wx.Panel):
         self.logfile = None  # log pathname, None otherwise
         self.result = []  # result of the final process
         self.count = 0  # keeps track of the counts (see `update_count`)
-        self.maxrotate = 0  # max num text rotation (see `update_count`)
         self.clr = self.appdata['colorscheme']
 
         wx.Panel.__init__(self, parent=parent)
@@ -219,15 +218,15 @@ class LogOut(wx.Panel):
             self.thread_type = FFmpeg(self.logfile, data)
 
         elif args[0] == 'video_to_sequence':
-            self.with_eta, self.maxrotate = False, None
+            self.with_eta = False
             self.thread_type = PicturesFromVideo(self.logfile, **data)
 
         elif args[0] == 'sequence_to_video':
-            self.maxrotate = None
+            self.with_eta = False
             self.thread_type = SlideshowMaker(self.logfile, **data)
 
         elif args[0] == 'concat_demuxer':
-            self.with_eta, self.maxrotate = False, None
+            self.with_eta = False
             self.thread_type = ConcatDemuxer(self.logfile, **data)
     # ----------------------------------------------------------------------
 
@@ -293,11 +292,10 @@ class LogOut(wx.Panel):
             ffprog = []
             for key, val in pairwise(out):
                 ffprog.append(f"{key}: {val}")
-
             if self.with_eta:
                 if 'speed=' in output:
                     speed = output.split('speed=')[-1].strip().split('x')[0]
-                    if speed in ('N/A', '0'):
+                    if speed in ('N/A', '0') or 'N/A' in speed:
                         eta = "   ETA: N/A"
                     else:  # is float
                         rem = (duration - msec) / float(speed)
@@ -338,11 +336,6 @@ class LogOut(wx.Panel):
             self.txtout.AppendText(f'\nERROR: {count}\n')
             self.error = True
         else:
-            if self.maxrotate is not None:
-                if self.maxrotate == 1:
-                    self.maxrotate = 0
-                    self.txtout.Clear()
-                self.maxrotate += 1
             self.barprog.SetRange(duration)  # set overall duration range
             self.barprog.SetValue(0)  # reset bar progress
             self.txtout.SetDefaultStyle(wx.TextAttr(self.clr['TXT0']))
@@ -419,7 +412,6 @@ class LogOut(wx.Panel):
         self.error = False
         self.result.clear()
         self.count = 0
-        self.maxrotate = 0
         self.with_eta = True  # restoring time remaining display
         self.btn_viewlog.Enable()
     # ----------------------------------------------------------------------
