@@ -5,9 +5,9 @@ Name: presets_manager.py
 Porpose: ffmpeg's presets manager panel
 Compatibility: Python3, wxPython Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
-Copyleft - 2024 Gianluca Pernigotto <jeanlucperni@gmail.com>
+Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
 license: GPL3
-Rev: Mar.22.2024
+Rev: July.17.2025
 Code checker: flake8, pylint
 
 This file is part of Videomass.
@@ -29,7 +29,6 @@ import time
 import os
 import sys
 import wx
-import wx.lib.scrolledpanel as scrolled
 from videomass.vdms_utils.get_bmpfromsvg import get_bmp
 from videomass.vdms_utils.presets_manager_utils import json_data
 from videomass.vdms_utils.presets_manager_utils import supported_formats
@@ -85,7 +84,7 @@ class PrstPan(wx.Panel):
         get = wx.GetApp()  # get data from bootstrap
         self.appdata = get.appset
         icons = get.iconset
-        self.src_prst = os.path.join(self.appdata['srcpath'], 'presets')
+        self.src_prst = os.path.join(self.appdata['srcdata'], 'presets')
         self.user_prst = os.path.join(self.appdata['confdir'], 'presets')
         self.array = []  # Parameters of the selected profile
         self.txtcmdedited = True  # show warning if cmdline is edited
@@ -96,109 +95,78 @@ class PrstPan(wx.Panel):
             bmpeditprf = get_bmp(icons['profile_edit'], ((16, 16)))
             bmpdelprf = get_bmp(icons['profile_del'], ((16, 16)))
             bmpcopyprf = get_bmp(icons['profile_copy'], ((16, 16)))
+            bmpdelprst = get_bmp(icons['delpreset'], ((16, 16)))
+            bmpexpall = get_bmp(icons['exportall'], ((16, 16)))
+            bmpexpsel = get_bmp(icons['exportselected'], ((16, 16)))
+            bmpimpdir = get_bmp(icons['importfolder'], ((16, 16)))
+            bmpimpprst = get_bmp(icons['importpreset'], ((16, 16)))
+            bmpnewprst = get_bmp(icons['newpreset'], ((16, 16)))
+            bmpreload = get_bmp(icons['reload'], ((16, 16)))
+            bmprestall = get_bmp(icons['restoreall'], ((16, 16)))
+            bmprestsel = get_bmp(icons['restoreselected'], ((16, 16)))
         else:
             bmpnewprf = wx.Bitmap(icons['profile_add'], wx.BITMAP_TYPE_ANY)
             bmpeditprf = wx.Bitmap(icons['profile_edit'], wx.BITMAP_TYPE_ANY)
             bmpdelprf = wx.Bitmap(icons['profile_del'], wx.BITMAP_TYPE_ANY)
             bmpcopyprf = wx.Bitmap(icons['profile_copy'], wx.BITMAP_TYPE_ANY)
+            bmpdelprst = wx.Bitmap(icons['delpreset'], wx.BITMAP_TYPE_ANY)
+            bmpexpall = wx.Bitmap(icons['exportall'], wx.BITMAP_TYPE_ANY)
+            bmpexpsel = wx.Bitmap(icons['exportselected'], wx.BITMAP_TYPE_ANY)
+            bmpimpdir = wx.Bitmap(icons['importfolder'], wx.BITMAP_TYPE_ANY)
+            bmpimpprst = wx.Bitmap(icons['importpreset'], wx.BITMAP_TYPE_ANY)
+            bmpnewprst = wx.Bitmap(icons['newpreset'], wx.BITMAP_TYPE_ANY)
+            bmpreload = wx.Bitmap(icons['reload'], wx.BITMAP_TYPE_ANY)
+            bmprestall = wx.Bitmap(icons['restoreall'], wx.BITMAP_TYPE_ANY)
+            bmprestsel = wx.Bitmap(icons['restoreselected'],
+                                   wx.BITMAP_TYPE_ANY)
 
         prst = sorted([os.path.splitext(x)[0] for x in
                        os.listdir(self.user_prst) if
                        os.path.splitext(x)[1] == '.json'
                        ])
         wx.Panel.__init__(self, parent, -1)
-
         sizer_base = wx.BoxSizer(wx.VERTICAL)
-        sizer_div = wx.BoxSizer(wx.HORIZONTAL)
-        sizer_base.Add(sizer_div, 1, wx.EXPAND)
         # ------- BOX PRESETS
-        boxpresets = wx.StaticBoxSizer(wx.StaticBox(
-            self, wx.ID_ANY, _('Presets')), wx.VERTICAL)
-        sizer_div.Add(boxpresets, 0, wx.ALL | wx.EXPAND, 5)
+        fgs1 = wx.BoxSizer(wx.HORIZONTAL)
         self.cmbx_prst = wx.ComboBox(self, wx.ID_ANY,
                                      choices=prst,
-                                     size=(200, -1),
+                                     size=(150, -1),
                                      style=wx.CB_DROPDOWN
                                      | wx.CB_READONLY,
                                      )
-        boxpresets.Add(self.cmbx_prst, 0, wx.ALL | wx.EXPAND, 5)
-        boxpresets.Add((5, 5))
-        line0 = wx.StaticLine(self, wx.ID_ANY, pos=wx.DefaultPosition,
-                              size=wx.DefaultSize, style=wx.LI_HORIZONTAL,
-                              name=wx.StaticLineNameStr
-                              )
-        boxpresets.Add(line0, 0, wx.ALL | wx.EXPAND, 5)
-        boxpresets.Add((5, 5))
-        panelscr = scrolled.ScrolledPanel(self, -1, size=(230, 500),
-                                          style=wx.TAB_TRAVERSAL
-                                          | wx.BORDER_THEME,
-                                          name="panelscroll",
-                                          )
-        fgs1 = wx.BoxSizer(wx.VERTICAL)
-        self.btn_newpreset = wx.Button(panelscr, wx.ID_ANY,
-                                       _("New"), size=(-1, -1))
-        fgs1.Add(self.btn_newpreset, 0, wx.ALL | wx.EXPAND, 5)
-        self.btn_delpreset = wx.Button(panelscr, wx.ID_ANY,
-                                       _("Remove"), size=(-1, -1))
-        fgs1.Add(self.btn_delpreset, 0, wx.ALL | wx.EXPAND, 5)
-        line1 = wx.StaticLine(panelscr, wx.ID_ANY, pos=wx.DefaultPosition,
-                              size=wx.DefaultSize, style=wx.LI_HORIZONTAL,
-                              name=wx.StaticLineNameStr
-                              )
-        fgs1.Add((5, 5))
-        fgs1.Add(line1, 0, wx.ALL | wx.EXPAND, 5)
-        fgs1.Add((5, 5))
-        self.btn_savecopy = wx.Button(panelscr, wx.ID_ANY,
-                                      _("Export selected"), size=(-1, -1))
-        fgs1.Add(self.btn_savecopy, 0, wx.ALL | wx.EXPAND, 5)
-        self.btn_saveall = wx.Button(panelscr, wx.ID_ANY,
-                                     _("Export all..."), size=(-1, -1))
-        fgs1.Add(self.btn_saveall, 0, wx.ALL | wx.EXPAND, 5)
-
-        line2 = wx.StaticLine(panelscr, wx.ID_ANY, pos=wx.DefaultPosition,
-                              size=wx.DefaultSize, style=wx.LI_HORIZONTAL,
-                              name=wx.StaticLineNameStr
-                              )
-        fgs1.Add((5, 5))
-        fgs1.Add(line2, 0, wx.ALL | wx.EXPAND, 5)
-        fgs1.Add((5, 5))
-        self.btn_restore = wx.Button(panelscr, wx.ID_ANY,
-                                     _("Import preset"), size=(-1, -1))
-        fgs1.Add(self.btn_restore, 0, wx.ALL | wx.EXPAND, 5)
-        self.btn_restoreall = wx.Button(panelscr, wx.ID_ANY,
-                                        _("Import folder"), size=(-1, -1))
-        fgs1.Add(self.btn_restoreall, 0, wx.ALL | wx.EXPAND, 5)
-
-        line3 = wx.StaticLine(panelscr, wx.ID_ANY, pos=wx.DefaultPosition,
-                              size=wx.DefaultSize, style=wx.LI_HORIZONTAL,
-                              name=wx.StaticLineNameStr
-                              )
-        fgs1.Add((5, 5))
-        fgs1.Add(line3, 0, wx.ALL | wx.EXPAND, 5)
-        fgs1.Add((5, 5))
-        self.btn_restoredef = wx.Button(panelscr, wx.ID_ANY,
-                                        _("Restore selected"), size=(-1, -1))
-        fgs1.Add(self.btn_restoredef, 0, wx.ALL | wx.EXPAND, 5)
-
-        self.btn_restorealldefault = wx.Button(panelscr, wx.ID_ANY,
-                                               _("Restore all..."),
-                                               size=(-1, -1)
-                                               )
-        fgs1.Add(self.btn_restorealldefault, 0, wx.ALL | wx.EXPAND, 5)
-        line4 = wx.StaticLine(panelscr, wx.ID_ANY, pos=wx.DefaultPosition,
-                              size=wx.DefaultSize, style=wx.LI_HORIZONTAL,
-                              name=wx.StaticLineNameStr
-                              )
-        fgs1.Add((5, 5))
-        fgs1.Add(line4, 0, wx.ALL | wx.EXPAND, 5)
-        fgs1.Add((5, 5))
-        self.btn_refresh = wx.Button(panelscr, wx.ID_ANY,
-                                     _("Reload all"), size=(-1, -1))
-        fgs1.Add(self.btn_refresh, 0, wx.ALL | wx.EXPAND, 5)
-        boxpresets.Add(panelscr, 0, wx.ALL | wx.CENTRE, 5)
-        panelscr.SetSizer(fgs1)
-        panelscr.SetAutoLayout(1)
-        panelscr.SetupScrolling()
+        fgs1.Add(self.cmbx_prst, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_newpreset = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_newpreset.SetBitmap(bmpnewprst, wx.LEFT)
+        fgs1.Add(self.btn_newpreset, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_delpreset = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_delpreset.SetBitmap(bmpdelprst, wx.LEFT)
+        fgs1.Add(self.btn_delpreset, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_savecopy = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_savecopy.SetBitmap(bmpexpsel, wx.LEFT)
+        fgs1.Add(self.btn_savecopy, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_saveall = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_saveall.SetBitmap(bmpexpall, wx.LEFT)
+        fgs1.Add(self.btn_saveall, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_restore = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_restore.SetBitmap(bmpimpprst, wx.LEFT)
+        fgs1.Add(self.btn_restore, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_restoreall = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_restoreall.SetBitmap(bmpimpdir, wx.LEFT)
+        fgs1.Add(self.btn_restoreall, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_restoredef = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_restoredef.SetBitmap(bmprestsel, wx.LEFT)
+        fgs1.Add(self.btn_restoredef, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_restorealldefault = wx.Button(self, wx.ID_ANY,
+                                               "", size=(40, -1))
+        self.btn_restorealldefault.SetBitmap(bmprestall, wx.LEFT)
+        fgs1.Add(self.btn_restorealldefault, 0, wx.ALL | wx.CENTRE, 5)
+        self.btn_refresh = wx.Button(self, wx.ID_ANY, "", size=(40, -1))
+        self.btn_refresh.SetBitmap(bmpreload, wx.LEFT)
+        fgs1.Add(self.btn_refresh, 0, wx.ALL | wx.CENTRE, 5)
+        boxprst = wx.StaticBox(self, wx.ID_ANY, _("Presets"))
+        boxpresets = wx.StaticBoxSizer(boxprst, wx.VERTICAL)
+        sizer_base.Add(boxpresets, 0, wx.ALL | wx.EXPAND, 5)
+        boxpresets.Add(fgs1, 0, wx.ALL, 5)
         # ------ LIST CONTROL & BOX PROFILES
         # --- listctrl
         self.lctrl = wx.ListCtrl(self, wx.ID_ANY,
@@ -206,13 +174,10 @@ class PrstPan(wx.Panel):
                                  | wx.SUNKEN_BORDER
                                  | wx.LC_SINGLE_SEL,
                                  )
-        boxprofiles = wx.StaticBoxSizer(wx.StaticBox(
-            self, wx.ID_ANY, _('Profiles')), wx.VERTICAL)
-        boxprofiles.Add(self.lctrl, 1, wx.ALL | wx.EXPAND, 5)
         # --- profile buttons
         grid_profiles = wx.FlexGridSizer(0, 4, 0, 5)
         self.btn_newprofile = wx.Button(self, wx.ID_ANY,
-                                        _("Add"), size=(-1, -1))
+                                        _("Write"), size=(-1, -1))
         self.btn_newprofile.SetBitmap(bmpnewprf, wx.LEFT)
         grid_profiles.Add(self.btn_newprofile, 0, wx.ALL, 0)
         self.btn_delprofile = wx.Button(self, wx.ID_ANY,
@@ -230,8 +195,11 @@ class PrstPan(wx.Panel):
         self.btn_copyprofile.SetBitmap(bmpcopyprf, wx.LEFT)
         self.btn_copyprofile.Disable()
         grid_profiles.Add(self.btn_copyprofile, 0, wx.ALL, 0)
+        boxprofiles = wx.StaticBoxSizer(wx.StaticBox(
+            self, wx.ID_ANY, _('Profiles')), wx.VERTICAL)
+        boxprofiles.Add(self.lctrl, 1, wx.ALL | wx.EXPAND, 5)
         boxprofiles.Add(grid_profiles, 0, wx.ALL, 5)
-        sizer_div.Add(boxprofiles, 1, wx.ALL | wx.EXPAND, 5)
+        sizer_base.Add(boxprofiles, 1, wx.ALL | wx.EXPAND, 5)
         # ------- command line
         grd_cmd = wx.BoxSizer(wx.HORIZONTAL)
         sizer_base.Add(grd_cmd, 0, wx.EXPAND)
@@ -259,6 +227,44 @@ class PrstPan(wx.Panel):
                                       style=wx.TE_PROCESS_ENTER,
                                       )
         box_cmd2.Add(self.pass_2_pre, 0, wx.ALL | wx.EXPAND, 5)
+
+        # ------- tipips
+        self.cmbx_prst.SetToolTip(_("Choose a preset and view its profiles"))
+        tip = _("Write a new profile and save it in the selected preset")
+        self.btn_newprofile.SetToolTip(tip)
+        self.btn_delprofile.SetToolTip(_("Delete the selected profile"))
+        self.btn_editprofile.SetToolTip(_("Edit the selected profile"))
+        self.btn_copyprofile.SetToolTip(_("Duplicate the selected profile"))
+        tip = _("Create new preset")
+        self.btn_newpreset.SetToolTip(tip)
+        tip = _("Remove selected preset")
+        self.btn_delpreset.SetToolTip(tip)
+        tip = _("Backup selected preset")
+        self.btn_savecopy.SetToolTip(tip)
+        tip = _("Backup the presets folder")
+        self.btn_saveall.SetToolTip(tip)
+        tip = _("Restore a preset")
+        self.btn_restore.SetToolTip(tip)
+        tip = _("Restore a presets folder")
+        self.btn_restoreall.SetToolTip(tip)
+        tip = _("Resets the selected preset to default values")
+        self.btn_restoredef.SetToolTip(tip)
+        tip = _("Reset all presets to default values")
+        self.btn_restorealldefault.SetToolTip(tip)
+        self.btn_refresh.SetToolTip(_("Refresh the presets list"))
+        tip = _('FFmpeg arguments for one-pass encoding')
+        self.txt_1cmd.SetToolTip(tip)
+        tip = _('FFmpeg arguments for two-pass encoding')
+        self.txt_2cmd.SetToolTip(tip)
+        tip = (_('Any optional arguments to add before input file on the '
+                 'one-pass encoding, e.g required names of some hardware '
+                 'accelerations like -hwaccel to use with CUDA.'))
+        self.pass_1_pre.SetToolTip(tip)
+        tip = (_('Any optional arguments to add before input file on the '
+                 'two-pass encoding, e.g required names of some hardware '
+                 'accelerations like -hwaccel to use with CUDA.'))
+        self.pass_2_pre.SetToolTip(tip)
+
         self.SetSizer(sizer_base)
         self.Layout()
 
@@ -281,42 +287,6 @@ class PrstPan(wx.Panel):
             self.txt_2cmd.SetFont(wx.Font(8, wx.FONTFAMILY_TELETYPE,
                                           wx.NORMAL, wx.NORMAL))
 
-        # ------- tipips
-        self.cmbx_prst.SetToolTip(_("Choose a preset and view its profiles"))
-        tip = _("Create a new profile and save it in the selected preset")
-        self.btn_newprofile.SetToolTip(tip)
-        self.btn_delprofile.SetToolTip(_("Delete the selected profile"))
-        self.btn_editprofile.SetToolTip(_("Edit the selected profile"))
-        tip = _("Create a new preset")
-        self.btn_newpreset.SetToolTip(tip)
-        tip = _("Remove the selected preset from the Presets Manager")
-        self.btn_delpreset.SetToolTip(tip)
-        tip = _("Export selected preset as copy")
-        self.btn_savecopy.SetToolTip(tip)
-        tip = _("Export entire presets folder as copy")
-        self.btn_saveall.SetToolTip(tip)
-        tip = _("Import a new preset or update an existing one")
-        self.btn_restore.SetToolTip(tip)
-        tip = _("Import a presets folder, updating those in use")
-        self.btn_restoreall.SetToolTip(tip)
-        tip = _("Replace the selected preset with the Videomass default one")
-        self.btn_restoredef.SetToolTip(tip)
-        tip = _("Retrieve all Videomass default presets")
-        self.btn_restorealldefault.SetToolTip(tip)
-        self.btn_refresh.SetToolTip(_("Update the presets list"))
-        tip = _('FFmpeg arguments for one-pass encoding')
-        self.txt_1cmd.SetToolTip(tip)
-        tip = _('FFmpeg arguments for two-pass encoding')
-        self.txt_2cmd.SetToolTip(tip)
-        tip = (_('Any optional arguments to add before input file on the '
-                 'one-pass encoding, e.g required names of some hardware '
-                 'accelerations like -hwaccel to use with CUDA.'))
-        self.pass_1_pre.SetToolTip(tip)
-        tip = (_('Any optional arguments to add before input file on the '
-                 'two-pass encoding, e.g required names of some hardware '
-                 'accelerations like -hwaccel to use with CUDA.'))
-        self.pass_2_pre.SetToolTip(tip)
-
         # ----------------------Binder (EVT)----------------------#
         self.Bind(wx.EVT_COMBOBOX, self.on_preset_selection, self.cmbx_prst)
         self.Bind(wx.EVT_BUTTON, self.profile_add, self.btn_newprofile)
@@ -371,7 +341,7 @@ class PrstPan(wx.Panel):
                     'latest versions of Videomass.\n\n'
                     'To avoid data loss and allow for possible recovery, '
                     'the outdated presets folder will be backed up in the '
-                    'program configuration directory: "{2}"\n\n'
+                    'program configuration directory:\n«{2}»\n\n'
                     'Do you want to perform this '
                     'update now?').format(srcversion,
                                           confversion,
@@ -435,10 +405,10 @@ class PrstPan(wx.Panel):
         self.lctrl.InsertColumn(2, _('Output Format'), width=colw[2])
         self.lctrl.InsertColumn(3, _('Supported Format List'), width=colw[3])
 
-        path = os.path.join(f'{self.user_prst}',
-                            f'{self.cmbx_prst.GetValue()}.json'
-                            )
-        collections = json_data(path)
+        tofile = os.path.join(self.user_prst,
+                              self.cmbx_prst.GetValue() + '.json'
+                              )
+        collections = json_data(tofile)
         if collections == 'error':
             return
         try:
@@ -451,8 +421,8 @@ class PrstPan(wx.Panel):
                 self.lctrl.SetItem(rows, 2, name["Output_extension"])
                 self.lctrl.SetItem(rows, 3, name["Supported_list"])
 
-        except (TypeError, KeyError):
-            wx.MessageBox(_('Preset not supported!\nFILE: "{}"'.format(path)),
+        except (TypeError, KeyError) as err:
+            wx.MessageBox(f"ERROR: {str(err)}.\nInvalid file: «{tofile}»",
                           _('Videomass - Error!'), wx.ICON_ERROR, self)
             return
     # ----------------------Event handler (callback)----------------------#
@@ -489,10 +459,10 @@ class PrstPan(wx.Panel):
         Event when selecting a profile in the lctrl,
         this update the request data of the objects.
         """
-        path = os.path.join(f'{self.user_prst}',
-                            f'{self.cmbx_prst.GetValue()}.json'
-                            )
-        collections = json_data(path)
+        tofile = os.path.join(self.user_prst,
+                              self.cmbx_prst.GetValue() + '.json'
+                              )
+        collections = json_data(tofile)
         selected = event.GetText()  # event.GetText is a Name Profile
         self.txt_1cmd.SetValue("")
         self.txt_2cmd.SetValue("")
@@ -516,8 +486,7 @@ class PrstPan(wx.Panel):
                     self.array.append(name["Preinput_2"])
 
         except KeyError as err:
-            wx.MessageBox(_('json key error\n'
-                            'FILE: "{0}"\n\n{1}'.format(path, err)),
+            wx.MessageBox(f'key error {str(err)}\nInvalid file: «{tofile}»',
                           _('Videomass - Error!'), wx.ICON_ERROR, self)
             return
 
@@ -543,24 +512,28 @@ class PrstPan(wx.Panel):
         filename = None
         with wx.FileDialog(self, _("Enter name for new preset"),
                            defaultDir=self.user_prst,
-                           wildcard="Videomass presets (*.json;)|*.json;",
+                           wildcard="Videomass preset (*.json;)|*.json;",
                            style=wx.FD_SAVE
                            | wx.FD_OVERWRITE_PROMPT) as fileDialog:
-
+            fileDialog.SetFilename('New preset.json')
             if fileDialog.ShowModal() == wx.ID_CANCEL:
                 return
-            filename = f"{fileDialog.GetPath()}.json"
+
+            filename = fileDialog.GetPath()
+            if os.path.splitext(filename)[1].strip() != '.json':
+                wx.LogError(_('Invalid file name, make sure to provide a '
+                              'valid name including the «.json» extension'))
+                return
             try:
                 with open(filename, 'w', encoding='utf-8') as file:
                     file.write('[]')
             except IOError:
                 wx.LogError(_("Cannot save current "
-                            "data in file '{}'.").format(filename))
+                              "data in file '{}'.").format(filename))
                 return
         if filename:
-            wx.MessageBox(_("'Successful!\n\n"
-                            "A new empty preset has been created."),
-                          "Videomass ", wx.ICON_INFORMATION, self)
+            wx.MessageBox(_("You just successfully created a new preset!"),
+                          "Videomass", wx.ICON_INFORMATION, self)
 
             self.reset_list(True)
             self.on_deselect(self, cleardata=False)
@@ -570,10 +543,10 @@ class PrstPan(wx.Panel):
         """
         Remove selected preset moving to the `Removals` folder
         """
-        filename = self.cmbx_prst.GetValue()
+        prstname = self.cmbx_prst.GetValue()
         if wx.MessageBox(_('Are you sure you want to remove "{}" preset?\n\n '
                            'It will be moved to the "Removals" subfolder '
-                           'inside the presets folder.').format(filename),
+                           'inside the presets folder.').format(prstname),
                          _('Please confirm'), wx.ICON_QUESTION
                          | wx.CANCEL | wx.YES_NO, self) != wx.YES:
             return
@@ -588,13 +561,13 @@ class PrstPan(wx.Panel):
                           )
             return
 
-        s = os.path.join(self.user_prst, f'{filename}.json')
-        d = os.path.join(self.user_prst, 'Removals', f'{filename}.json')
+        s = os.path.join(self.user_prst, prstname + '.json')
+        d = os.path.join(self.user_prst, 'Removals', prstname + '.json')
         os.replace(s, d)
 
         wx.MessageBox(_('The preset "{0}" was successfully '
-                        'removed').format(filename), _('Videomass - Error!'),
-                      wx.ICON_ERROR, self
+                        'removed').format(prstname), 'Videomass',
+                      wx.OK, self
                       )
         self.reset_list(True)
         self.on_deselect(self, cleardata=False)
@@ -605,28 +578,28 @@ class PrstPan(wx.Panel):
         save one preset on media
         """
         combvalue = self.cmbx_prst.GetValue()
-        filedir = f'{self.user_prst}/{combvalue}.json'
+        tofile = os.path.join(self.user_prst, combvalue + '.json')
 
-        dlg = wx.DirDialog(self, _("Choose Destination"),
+        dlg = wx.DirDialog(self, _("Open a destination folder"),
                            "", style=wx.DD_DEFAULT_STYLE)
         if dlg.ShowModal() == wx.ID_OK:
             path = dlg.GetPath()
-            if os.path.exists(os.path.join(path, f'{combvalue}.json')):
+            if os.path.exists(os.path.join(path, combvalue + '.json')):
                 if wx.MessageBox(_('A file with this name already exists, '
                                    'do you want to overwrite it?'),
                                  _('Please confirm'), wx.ICON_QUESTION
                                  | wx.CANCEL | wx.YES_NO, self) != wx.YES:
                     return
 
-            status = copy_restore(filedir,
-                                  os.path.join(path, f'{combvalue}.json'))
+            status = copy_restore(tofile,
+                                  os.path.join(path, combvalue + '.json'))
             dlg.Destroy()
 
             if status:
                 wx.MessageBox(f'{status}', _('Videomass - Error!'),
                               wx.ICON_ERROR, self)
                 return
-            wx.MessageBox(_("The preset was exported successfully"),
+            wx.MessageBox(_("Backup completed successfully"),
                           "Videomass", wx.OK, self)
     # ------------------------------------------------------------------#
 
@@ -636,17 +609,17 @@ class PrstPan(wx.Panel):
         """
         src = self.user_prst
 
-        dialsave = wx.DirDialog(self, _("Choose Destination"),
+        dialsave = wx.DirDialog(self, _("Open a destination folder"),
                                 "", wx.DD_DEFAULT_STYLE)
         if dialsave.ShowModal() == wx.ID_OK:
             dest = dialsave.GetPath()
-            status = copydir_recursively(src, dest, 'Videomass-Presets-copy')
+            status = copydir_recursively(src, dest, 'Videomass-presets-backup')
             dialsave.Destroy()
             if status:
                 wx.MessageBox(f'{status}', _('Videomass - Error!'),
                               wx.ICON_ERROR, self)
             else:
-                wx.MessageBox(_("All presets have been exported successfully"),
+                wx.MessageBox(_("Backup completed successfully"),
                               "Videomass", wx.OK, self)
     # ------------------------------------------------------------------#
 
@@ -655,10 +628,10 @@ class PrstPan(wx.Panel):
         Import a new preset. If the preset already exists you will
         be asked to overwrite it or not.
         """
-        wildcard = "Source (*.json)|*.json| All files (*.*)|*.*"
-
-        with wx.FileDialog(self, _("Import a new preset"),
-                           "", "", wildcard, wx.FD_OPEN
+        with wx.FileDialog(self, _("Open the preset you want to restore"),
+                           defaultDir=os.path.expanduser('~'),
+                           wildcard="Videomass preset (*.json;)|*.json;",
+                           style=wx.FD_OPEN
                            | wx.FD_FILE_MUST_EXIST) as filedlg:
 
             if filedlg.ShowModal() == wx.ID_CANCEL:
@@ -667,13 +640,6 @@ class PrstPan(wx.Panel):
             newincoming = filedlg.GetPath()
             new = os.path.basename(newincoming)
 
-        if not newincoming.endswith('.json'):
-            wx.MessageBox(_('Error, invalid preset: "{}"').format(
-                          os.path.basename(newincoming)),
-                          _('Videomass - Error!'), wx.ICON_ERROR, self
-                          )
-            return
-
         if os.path.exists(os.path.join(self.user_prst, new)):
 
             if wx.MessageBox(_("This preset already exists and is about to be "
@@ -694,7 +660,7 @@ class PrstPan(wx.Panel):
 
         self.reset_list(True)  # reload presets
         self.on_deselect(self, cleardata=False)
-        wx.MessageBox(_("A new preset was successfully imported"),
+        wx.MessageBox(_("Restore successful"),
                       "Videomass", wx.OK, self)
     # ------------------------------------------------------------------#
 
@@ -719,7 +685,8 @@ class PrstPan(wx.Panel):
                              | wx.CANCEL | wx.YES_NO, self) != wx.YES:
                 return None
 
-            dialsave = wx.DirDialog(self, _("Import a new presets folder"),
+            dialsave = wx.DirDialog(self,
+                                    _("Open the presets folder to restore"),
                                     "", style=wx.DD_DEFAULT_STYLE)
             if dialsave.ShowModal() == wx.ID_CANCEL:
                 return None
@@ -749,7 +716,7 @@ class PrstPan(wx.Panel):
                 return err
         # copies non-existent ones to the destination directory
         if event:  # only `Import group` event
-            err = copy_on('prst', source, self.user_prst, overw=False)
+            err = copy_on('json', source, self.user_prst, overw=False)
             if err:
                 wx.MessageBox(f"{err}", _('Videomass - Error!'),
                               wx.ICON_ERROR, self)
@@ -766,6 +733,15 @@ class PrstPan(wx.Panel):
         """
         Replace the selected preset at default values.
         """
+        combvalue = self.cmbx_prst.GetValue()
+        sourceprst = os.path.join(self.src_prst, combvalue + '.json')
+        userprst = os.path.join(self.user_prst, combvalue + '.json')
+        if not os.path.exists(sourceprst) and not os.path.isfile(sourceprst):
+            wx.MessageBox(_("The selected preset is not part of Videomass's "
+                            "default presets."),
+                          "Videomass", wx.ICON_INFORMATION, self)
+            return
+
         msg = _("Be careful! The selected preset will be "
                 "overwritten with the default one. Your profiles "
                 "may be deleted!\n\nDo you want to continue?"
@@ -775,11 +751,7 @@ class PrstPan(wx.Panel):
                          | wx.YES_NO
                          | wx.CANCEL,
                          self) == wx.YES:
-
-            filename = self.cmbx_prst.GetValue()
-            status = copy_restore(f'{self.src_prst}/{filename}.json',
-                                  f'{self.user_prst}/{filename}.json'
-                                  )
+            status = copy_restore(sourceprst, userprst)
             if status:
                 wx.MessageBox(status, _('Videomass - Error!'),
                               wx.ICON_ERROR, self)
@@ -819,8 +791,7 @@ class PrstPan(wx.Panel):
                 wx.MessageBox(f"{err}", _('Videomass - Error!'),
                               wx.ICON_ERROR, self)
             else:
-                wx.MessageBox(_("All default presets have been "
-                                "successfully recovered"),
+                wx.MessageBox(_("Successful recovery"),
                               "Videomass", wx.OK, self)
                 self.reset_list(True)
                 self.on_deselect(self, cleardata=False)
@@ -838,11 +809,12 @@ class PrstPan(wx.Panel):
         """
         Store new profiles in the selected preset
         """
-        filename = self.cmbx_prst.GetValue()
-        title = _('New Profile - Preset "{}"').format(filename)
+        selprst = self.cmbx_prst.GetValue()
+        tofile = os.path.join(self.user_prst, selprst + '.json')
+        title = _('Write profile on «{0}»').format(selprst)
         prstdialog = setting_profiles.SettingProfile(self,
                                                      'newprofile',
-                                                     filename,
+                                                     tofile,
                                                      None,
                                                      title,
                                                      )
@@ -856,11 +828,12 @@ class PrstPan(wx.Panel):
         """
         Edit an existing profile
         """
-        filename = self.cmbx_prst.GetValue()
-        title = _('*Edit Profile - Preset "{}"').format(filename)
+        selprst = self.cmbx_prst.GetValue()
+        tofile = os.path.join(self.user_prst, selprst + '.json')
+        title = _('Edit profile on «{0}»').format(selprst)
         prstdialog = setting_profiles.SettingProfile(self,
                                                      'edit',
-                                                     filename,
+                                                     tofile,
                                                      self.array,
                                                      title)
         ret = prstdialog.ShowModal()
@@ -873,10 +846,10 @@ class PrstPan(wx.Panel):
         """
         Copy (duplicate) selected profile
         """
-        filename = os.path.join(f'{self.user_prst}',
-                                f'{self.cmbx_prst.GetValue()}.json'
-                                )
-        newprst = write_new_profile(filename,
+        tofile = os.path.join(self.user_prst,
+                              self.cmbx_prst.GetValue() + '.json'
+                              )
+        newprst = write_new_profile(tofile,
                                     Name=f'{self.array[0]} (duplicated)',
                                     Description=self.array[1],
                                     First_pass=self.array[2],
@@ -902,10 +875,10 @@ class PrstPan(wx.Panel):
                          wx.ICON_WARNING | wx.YES_NO | wx.CANCEL,
                          self) == wx.YES:
 
-            filename = os.path.join(f'{self.user_prst}',
-                                    f'{self.cmbx_prst.GetValue()}.json'
-                                    )
-            delete_profiles(filename, self.array[0])
+            tofile = os.path.join(self.user_prst,
+                                  self.cmbx_prst.GetValue() + '.json'
+                                  )
+            delete_profiles(tofile, self.array[0])
             self.reset_list()
             self.on_deselect(self, cleardata=False)
     # ------------------------------------------------------------------#
